@@ -229,7 +229,6 @@ CmFigure* CmModel::GetCmFigure(CmPage *page,
 }
 
 void CmModel::ParseModelCommands(CmString &buffer) {
-  CmModelMethodProc cmm;
   int escape_length = escape.Length();
 
   while (buffer.Contains(escape_regex)) {
@@ -243,22 +242,14 @@ void CmModel::ParseModelCommands(CmString &buffer) {
 
       switch (command_line[escape_length]) {
       case '!':
-	cmm = FindMethod(cds->NextToken(command_chars));
-	if (cmm)
-	  cmm(command_chars, this);
-	break;
+	FindMethod(command_chars); break;
       case '-':
 	command_buffer += command_chars;
-	const char *command_buffer_chars = command_buffer.Chars();
-	
 	if (trace_level > 1)
 	  (*evaluator) << "\nBegin CDS Command\n" << 
 	    command_buffer << "End CDS Command\n";
 	
-	cmm = FindMethod(cds->NextToken(command_buffer_chars));
-	
-	if ( cmm )
-	  cmm(command_buffer_chars, this);
+	FindMethod(command_buffer.Chars());
 	command_buffer = "";
 	break;
       case '+':
